@@ -3,17 +3,18 @@ use warnings;
 
 package Dist::Zilla::PluginBundle::KENTNL;
 BEGIN {
-  $Dist::Zilla::PluginBundle::KENTNL::VERSION = '0.01017322';
+  $Dist::Zilla::PluginBundle::KENTNL::VERSION = '0.01023311';
 }
 
 # ABSTRACT: BeLike::KENTNL when you build your distributions.
 
 use Moose;
 use Moose::Autobox;
+use Class::Load qw( :all );
 
 with 'Dist::Zilla::Role::PluginBundle';
 
-use namespace::autoclean -also => [qw( _expand _load _defined_or _only_git _only_cpan _release_fail )];
+use namespace::autoclean -also => [qw( _expand _defined_or _only_git _only_cpan _release_fail )];
 
 
 
@@ -22,31 +23,20 @@ sub _expand {
   ## no critic ( RequireInterpolationOfMetachars )
   if ( ref $suffix ) {
     my ( $corename, $rename ) = @{$suffix};
-    if ( exists $conf->{-name} ){
-        $rename = delete $conf->{-name};
+    if ( exists $conf->{-name} ) {
+      $rename = delete $conf->{-name};
     }
     return [ q{@KENTNL/} . $corename . q{/} . $rename, 'Dist::Zilla::Plugin::' . $corename, $conf ];
   }
-  if ( exists $conf->{-name} ){
-        my $rename;
-        $rename = sprintf q{%s/%s}, $suffix , ( delete $conf->{-name} );
-        return [ q{@KENTNL/} . $rename, 'Dist::Zilla::Plugin::' . $suffix, $conf ];
+  if ( exists $conf->{-name} ) {
+    my $rename;
+    $rename = sprintf q{%s/%s}, $suffix, ( delete $conf->{-name} );
+    return [ q{@KENTNL/} . $rename, 'Dist::Zilla::Plugin::' . $suffix, $conf ];
 
   }
   return [ q{@KENTNL/} . $suffix, 'Dist::Zilla::Plugin::' . $suffix, $conf ];
 }
 
-sub _load {
-  my $m = shift;
-  eval " require $m ; 1" or do {
-    ## no critic (ProhibitPunctuationVars)
-    my $e = $@;
-    require Carp;
-    Carp::confess($e);
-  };
-  return;
-}
-
 
 sub _defined_or {
 
@@ -108,6 +98,13 @@ sub _if_twitter {
   return @{$else};
 }
 
+sub _if_git_versions {
+  my ( $args, $gitversions, $else ) = @_;
+  return @{$gitversions} if exists $ENV{KENTNL_GITVERSIONS};
+  return @{$gitversions} if exists $args->{git_versions};
+  return @{$else};
+}
+
 sub bundle_config {
   my ( $self, $section ) = @_;
   my $class = ( ref $self ) || $self;
@@ -119,19 +116,25 @@ sub bundle_config {
 
   my @config = map { _expand( $class, $_->[0], $_->[1] ) } (
     [
-      'AutoVersion::Relative' => {
-        major     => _defined_or( $arg, version_major         => 0 ),
-        minor     => _defined_or( $arg, version_minor         => 1 ),
-        year      => _defined_or( $arg, version_rel_year      => 2010 ),
-        month     => _defined_or( $arg, version_rel_month     => 5 ),
-        day       => _defined_or( $arg, version_rel_day       => 16 ),
-        hour      => _defined_or( $arg, version_rel_hour      => 20 ),
-        time_zone => _defined_or( $arg, version_rel_time_zone => 'Pacific/Auckland' ),
-      }
+      _if_git_versions(
+        $arg,
+        [ 'Git::NextVersion' => { version_regexp => '^(.*)-source$', first_version => 0.01000 } ],
+        [
+          'AutoVersion::Relative' => {
+            major     => _defined_or( $arg, version_major         => 0 ),
+            minor     => _defined_or( $arg, version_minor         => 1 ),
+            year      => _defined_or( $arg, version_rel_year      => 2010 ),
+            month     => _defined_or( $arg, version_rel_month     => 5 ),
+            day       => _defined_or( $arg, version_rel_day       => 16 ),
+            hour      => _defined_or( $arg, version_rel_hour      => 20 ),
+            time_zone => _defined_or( $arg, version_rel_time_zone => 'Pacific/Auckland' ),
+          }
+        ]
+      )
     ],
-    [ 'GatherDir'  => {} ],
+    [ 'GatherDir'  => { include_dotfiles => 1 } ],
     [ 'MetaConfig' => {} ],
-    [ 'PruneCruft' => {} ],
+    [ 'PruneCruft' => { except => '^.perltidyrc' } ],
     _only_git( $arg, [ 'GithubMeta' => {} ] ),
     [ 'License'               => {} ],
     [ 'PkgVersion'            => {} ],
@@ -144,19 +147,35 @@ sub bundle_config {
     [ 'ManifestSkip'          => {} ],
     [ 'Manifest'              => {} ],
     [ 'AutoPrereqs'           => {} ],
-    [ 'Prereqs' => { -name => 'BundleDevelNeeds' , -phase => 'develop' , -type => 'requires' , 'Dist::Zilla::PluginBundle::KENTNL::Lite' => 0 }],
-    [ 'Prereqs' => { -name => 'BundleDevelRecommends' , -phase => 'develop' , -type => 'recommends' , 'Dist::Zilla::PluginBundle::KENTNL::Lite' => 0.01009803 }],
-    [ 'Prereqs' => { -name => 'BundleDevelSuggests' , -phase => 'develop' , -type => 'suggests' , 'Dist::Zilla::PluginBundle::KENTNL' => 0.01017119 }],
+    [
+      'Prereqs' =>
+        { -name => 'BundleDevelNeeds', -phase => 'develop', -type => 'requires', 'Dist::Zilla::PluginBundle::KENTNL::Lite' => 0 }
+    ],
+    [
+      'Prereqs' => {
+        -name                                     => 'BundleDevelRecommends',
+        -phase                                    => 'develop',
+        -type                                     => 'recommends',
+        'Dist::Zilla::PluginBundle::KENTNL::Lite' => 0.01009803
+      }
+    ],
+    [
+      'Prereqs' => {
+        -name                               => 'BundleDevelSuggests',
+        -phase                              => 'develop',
+        -type                               => 'suggests',
+        'Dist::Zilla::PluginBundle::KENTNL' => 0.01017119
+      }
+    ],
 
-    [ 'MetaData::BuiltWith'   => { show_uname => 1, uname_args => q{ -s -o -r -m -i } } ],
-    [ 'CompileTests'          => {} ],
-    [ 'CriticTests'           => {} ],
-    [ 'MetaTests'             => {} ],
-    [ 'PodCoverageTests'      => {} ],
-    [ 'PodSyntaxTests'        => {} ],
-    [ 'ReportVersions::Tiny'  => {} ],
-    [ 'KwaliteeTests'         => {} ],
-    [ 'PortabilityTests'      => {} ],
+    [ 'MetaData::BuiltWith'  => { show_uname => 1, uname_args => q{ -s -o -r -m -i } } ],
+    [ 'CompileTests'         => {} ],
+    [ 'CriticTests'          => {} ],
+    [ 'MetaTests'            => {} ],
+    [ 'PodCoverageTests'     => {} ],
+    [ 'PodSyntaxTests'       => {} ],
+    [ 'ReportVersions::Tiny' => {} ],
+    [ 'KwaliteeTests'        => {} ],
     [ 'EOLTests'       => { trailing_whitespace => 1, } ],
     [ 'ExtraTests'     => {} ],
     [ 'TestRelease'    => {} ],
@@ -168,16 +187,16 @@ sub bundle_config {
         _release_fail($arg),
         _only_git( $arg, [ 'Git::Check' => { filename => 'Changes' } ] ),
         [ 'NextRelease' => {} ],
-        _only_git( $arg, [ [ 'Git::Tag', 'tag_master' ] => { filename => 'Changes', tag_format => '%v-source' } ] ),
+        _only_git( $arg, [ [ 'Git::Tag', 'tag_master' ] => { tag_format => '%v-source' } ] ),
         _only_git( $arg, [ 'Git::Commit' => {} ] ),
         _only_git( $arg, [ 'Git::CommitBuild' => { release_branch => 'releases' } ] ),
-        _only_git( $arg, [ [ 'Git::Tag', 'tag_release' ] => { filename => 'Changes', tag_format => '%v' } ] ),
+        _only_git( $arg, [ [ 'Git::Tag', 'tag_release' ] => { branch => 'releases', tag_format => '%v' } ] ),
         _only_cpan( $arg, [ 'UploadToCPAN' => {} ] ),
         _only_cpan( $arg, _only_twitter( $arg, [ 'Twitter' => $twitter_conf ] ) ),
       ]
     )
   );
-  _load( $_->[1] ) for @config;
+  load_class( $_->[1] ) for @config;
   return @config;
 }
 __PACKAGE__->meta->make_immutable;
@@ -196,7 +215,7 @@ Dist::Zilla::PluginBundle::KENTNL - BeLike::KENTNL when you build your distribut
 
 =head1 VERSION
 
-version 0.01017322
+version 0.01023311
 
 =head1 SYNOPSIS
 
@@ -205,6 +224,7 @@ version 0.01017322
     no_git  = 1 ; skip things that work with git.
     twitter_only = 1 ; skip uploading to cpan, don't git, but twitter with fakerelease.
     release_fail = 1 ; asplode!. ( non-twitter only )
+    git_versions = 1 ;  use git::nextversion for versioning
 
 =head1 DESCRIPTION
 
@@ -243,7 +263,7 @@ Kent Fredric <kentnl@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Kent Fredric.
+This software is copyright (c) 2011 by Kent Fredric.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
